# crimeserieslinkage
Statistical methods for identifying serial crimes and related offenders

The module «crimeserieslinkage» for Python is designed to automate research related to the study of signs of serial crimes of various types, allowing to identify those crimes that are committed by the same person (group of persons), as well as to establish the most similar suspect, information about which has already existed in the database of persons previously committed similar crimes.

The functions from this module allow to solve the following problems: the establishment of signs that allow identifying serial (linkage) crimes and serial offenders; determine in the array of unsolved criminal cases those of them that are serial and committed by the same suspect; identification of the most likely suspect from among persons accounted for in the database of persons who have committed similar crimes.
